==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkWidgetRepresentation.java <==
// java wrapper for vtkWidgetRepresentation object
//

package vtk;
import vtk.*;

public class vtkWidgetRepresentation extends vtkProp
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void PickingManagedOn_2();
  public void PickingManagedOn()
    { PickingManagedOn_2(); }

  private native void PickingManagedOff_3();
  public void PickingManagedOff()
    { PickingManagedOff_3(); }

  private native void SetPickingManaged_4(boolean id0);
  public void SetPickingManaged(boolean id0)
    { SetPickingManaged_4(id0); }

  private native boolean GetPickingManaged_5();
  public boolean GetPickingManaged()
    { return GetPickingManaged_5(); }

  private native void SetRenderer_6(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_6(id0); }

  private native long GetRenderer_7();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_7();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void BuildRepresentation_8();
  public void BuildRepresentation()
    { BuildRepresentation_8(); }

  private native void StartWidgetInteraction_9(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_9(id0); }

  private native void WidgetInteraction_10(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_10(id0); }

  private native void EndWidgetInteraction_11(double id0[]);
  public void EndWidgetInteraction(double id0[])
    { EndWidgetInteraction_11(id0); }

  private native int ComputeInteractionState_12(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_12(id0,id1,id2); }

  private native int GetInteractionState_13();
  public int GetInteractionState()
    { return GetInteractionState_13(); }

  private native void Highlight_14(int id0);
  public void Highlight(int id0)
    { Highlight_14(id0); }

  private native void SetPlaceFactor_15(double id0);
  public void SetPlaceFactor(double id0)
    { SetPlaceFactor_15(id0); }

  private native double GetPlaceFactorMinValue_16();
  public double GetPlaceFactorMinValue()
    { return GetPlaceFactorMinValue_16(); }

  private native double GetPlaceFactorMaxValue_17();
  public double GetPlaceFactorMaxValue()
    { return GetPlaceFactorMaxValue_17(); }

  private native double GetPlaceFactor_18();
  public double GetPlaceFactor()
    { return GetPlaceFactor_18(); }

  private native void SetHandleSize_19(double id0);
  public void SetHandleSize(double id0)
    { SetHandleSize_19(id0); }

  private native double GetHandleSizeMinValue_20();
  public double GetHandleSizeMinValue()
    { return GetHandleSizeMinValue_20(); }

  private native double GetHandleSizeMaxValue_21();
  public double GetHandleSizeMaxValue()
    { return GetHandleSizeMaxValue_21(); }

  private native double GetHandleSize_22();
  public double GetHandleSize()
    { return GetHandleSize_22(); }

  private native int GetNeedToRender_23();
  public int GetNeedToRender()
    { return GetNeedToRender_23(); }

  private native void SetNeedToRender_24(int id0);
  public void SetNeedToRender(int id0)
    { SetNeedToRender_24(id0); }

  private native int GetNeedToRenderMinValue_25();
  public int GetNeedToRenderMinValue()
    { return GetNeedToRenderMinValue_25(); }

  private native int GetNeedToRenderMaxValue_26();
  public int GetNeedToRenderMaxValue()
    { return GetNeedToRenderMaxValue_26(); }

  private native void NeedToRenderOn_27();
  public void NeedToRenderOn()
    { NeedToRenderOn_27(); }

  private native void NeedToRenderOff_28();
  public void NeedToRenderOff()
    { NeedToRenderOff_28(); }

  private native double[] GetBounds_29();
  public double[] GetBounds()
    { return GetBounds_29(); }

  private native void ShallowCopy_30(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_30(id0); }

  private native void GetActors_31(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_31(id0); }

  private native void GetActors2D_32(vtkPropCollection id0);
  public void GetActors2D(vtkPropCollection id0)
    { GetActors2D_32(id0); }

  private native void GetVolumes_33(vtkPropCollection id0);
  public void GetVolumes(vtkPropCollection id0)
    { GetVolumes_33(id0); }

  private native void ReleaseGraphicsResources_34(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_34(id0); }

  private native int RenderOverlay_35(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_35(id0); }

  private native int RenderOpaqueGeometry_36(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_36(id0); }

  private native int RenderTranslucentPolygonalGeometry_37(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_37(id0); }

  private native int RenderVolumetricGeometry_38(vtkViewport id0);
  public int RenderVolumetricGeometry(vtkViewport id0)
    { return RenderVolumetricGeometry_38(id0); }

  private native int HasTranslucentPolygonalGeometry_39();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_39(); }

  public vtkWidgetRepresentation() { super(); }

  public vtkWidgetRepresentation(long id) { super(id); }

}

==> vtk-8.2.0-19-aarch64.pkg.tar.xz: vtk/vtkWidgetRepresentation.java <==
// java wrapper for vtkWidgetRepresentation object
//

package vtk;
import vtk.*;

public class vtkWidgetRepresentation extends vtkProp
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void PickingManagedOn_2();
  public void PickingManagedOn()
    { PickingManagedOn_2(); }

  private native void PickingManagedOff_3();
  public void PickingManagedOff()
    { PickingManagedOff_3(); }

  private native void SetPickingManaged_4(boolean id0);
  public void SetPickingManaged(boolean id0)
    { SetPickingManaged_4(id0); }

  private native boolean GetPickingManaged_5();
  public boolean GetPickingManaged()
    { return GetPickingManaged_5(); }

  private native void SetRenderer_6(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_6(id0); }

  private native long GetRenderer_7();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_7();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void BuildRepresentation_8();
  public void BuildRepresentation()
    { BuildRepresentation_8(); }

  private native void StartWidgetInteraction_9(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_9(id0); }

  private native void WidgetInteraction_10(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_10(id0); }

  private native void EndWidgetInteraction_11(double id0[]);
  public void EndWidgetInteraction(double id0[])
    { EndWidgetInteraction_11(id0); }

  private native int ComputeInteractionState_12(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_12(id0,id1,id2); }

  private native int GetInteractionState_13();
  public int GetInteractionState()
    { return GetInteractionState_13(); }

  private native void Highlight_14(int id0);
  public void Highlight(int id0)
    { Highlight_14(id0); }

  private native void SetPlaceFactor_15(double id0);
  public void SetPlaceFactor(double id0)
    { SetPlaceFactor_15(id0); }

  private native double GetPlaceFactorMinValue_16();
  public double GetPlaceFactorMinValue()
    { return GetPlaceFactorMinValue_16(); }

  private native double GetPlaceFactorMaxValue_17();
  public double GetPlaceFactorMaxValue()
    { return GetPlaceFactorMaxValue_17(); }

  private native double GetPlaceFactor_18();
  public double GetPlaceFactor()
    { return GetPlaceFactor_18(); }

  private native void SetHandleSize_19(double id0);
  public void SetHandleSize(double id0)
    { SetHandleSize_19(id0); }

  private native double GetHandleSizeMinValue_20();
  public double GetHandleSizeMinValue()
    { return GetHandleSizeMinValue_20(); }

  private native double GetHandleSizeMaxValue_21();
  public double GetHandleSizeMaxValue()
    { return GetHandleSizeMaxValue_21(); }

  private native double GetHandleSize_22();
  public double GetHandleSize()
    { return GetHandleSize_22(); }

  private native int GetNeedToRender_23();
  public int GetNeedToRender()
    { return GetNeedToRender_23(); }

  private native void SetNeedToRender_24(int id0);
  public void SetNeedToRender(int id0)
    { SetNeedToRender_24(id0); }

  private native int GetNeedToRenderMinValue_25();
  public int GetNeedToRenderMinValue()
    { return GetNeedToRenderMinValue_25(); }

  private native int GetNeedToRenderMaxValue_26();
  public int GetNeedToRenderMaxValue()
    { return GetNeedToRenderMaxValue_26(); }

  private native void NeedToRenderOn_27();
  public void NeedToRenderOn()
    { NeedToRenderOn_27(); }

  private native void NeedToRenderOff_28();
  public void NeedToRenderOff()
    { NeedToRenderOff_28(); }

  private native double[] GetBounds_29();
  public double[] GetBounds()
    { return GetBounds_29(); }

  private native void ShallowCopy_30(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_30(id0); }

  private native void GetActors_31(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_31(id0); }

  private native void GetActors2D_32(vtkPropCollection id0);
  public void GetActors2D(vtkPropCollection id0)
    { GetActors2D_32(id0); }

  private native void GetVolumes_33(vtkPropCollection id0);
  public void GetVolumes(vtkPropCollection id0)
    { GetVolumes_33(id0); }

  private native void ReleaseGraphicsResources_34(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_34(id0); }

  private native int RenderOverlay_35(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_35(id0); }

  private native int RenderOpaqueGeometry_36(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_36(id0); }

  private native int RenderTranslucentPolygonalGeometry_37(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_37(id0); }

  private native int RenderVolumetricGeometry_38(vtkViewport id0);
  public int RenderVolumetricGeometry(vtkViewport id0)
    { return RenderVolumetricGeometry_38(id0); }

  private native int HasTranslucentPolygonalGeometry_39();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_39(); }

  private native void RegisterPickers_40();
  public void RegisterPickers()
    { RegisterPickers_40(); }

  private native void UnRegisterPickers_41();
  public void UnRegisterPickers()
    { UnRegisterPickers_41(); }

  public vtkWidgetRepresentation() { super(); }

  public vtkWidgetRepresentation(long id) { super(id); }

}
